#!/usr/bin/perl -w
#
# mod_auth_tkt logout script
# 
# Note that this needs script needs to be available locally on all domains 
#   if using multiple domains (unlike login.cgi, which only needs to exist
#   on one domain).
#

use File::Basename;
use CGI qw(:standard);
use URI;
use strict;

# ------------------------------------------------------------------------
# Configure this section to match your login.cgi

# Cookie names
my $AUTH_COOKIE_NAME = 'auth_tkt';
my $BACK_COOKIE_NAME = 'back';
my $BACK_ARG_NAME = 'back';

# ------------------------------------------------------------------------
# Setup some initial parameters
my $debug = 0;
my $q = CGI->new;
my ($server_name, $server_port) = split /:/, $ENV{HTTP_HOST};
$server_name ||= $ENV{SERVER_NAME};
$server_port ||= $ENV{SERVER_PORT};
my $AUTH_DOMAIN = $ENV{AUTH_DOMAIN};
unless ($AUTH_DOMAIN) {
  # If no AUTH_DOMAIN set, default to server wildcard domain (.foo.com)
  $AUTH_DOMAIN = $server_name;
  $AUTH_DOMAIN =~ s/^[^\.]*// if $AUTH_DOMAIN;
}
my $back = $q->cookie($BACK_COOKIE_NAME) || $q->param($BACK_ARG_NAME);
if ($back && $back =~ m!^/!) {
  my $hostname = $server_name;
  my $port = $server_port;
  $hostname .= ':' . $port if $port && $port != 80 && $port != 443;
  $back = sprintf "http%s://%s%s", ($port == 443 ? 's' : ''), $hostname, $back;
} elsif ($back && $back !~ m/^http/i) {
  $back = 'http://' . $back;
}

# Logout by resetting the auth cookie
my $cookie_fmt = $AUTH_DOMAIN ? "%s=; domain=%s; path=/" : "%s=; path=/";
my $redirected = 0;
if ($back) {
  my $b = URI->new($back);
  # If $back domain doesn't match $AUTH_DOMAIN, add ticket reset to back
  my $domain = $AUTH_DOMAIN || $server_name;
  if ($b->host !~ m/\b$domain$/i) {
    $back .= $b->query ? '&' : '?';
    $back .= $AUTH_COOKIE_NAME . '=';
  }

  if ($debug) {
    print $q->header(-cookie => sprintf($cookie_fmt, $AUTH_COOKIE_NAME, $AUTH_DOMAIN));
  }

  else {
    # Set (local) cookie, and redirect to $back
    print $q->header(
      -cookie => sprintf($cookie_fmt, $AUTH_COOKIE_NAME, $AUTH_DOMAIN),
      -location => $back,
    );
    $redirected = 1;
  }
}

# If no $back, just set the auth cookie and hope for the best
else {
  print $q->header(-cookie => sprintf($cookie_fmt, $AUTH_COOKIE_NAME, $AUTH_DOMAIN));
}

unless ($redirected) {
  # If here, either some kind of error or no back ref found
  print $q->header,
    $q->start_html(
      -title => "Logout Page",
    );
  print <<EOD;
<div align="center">
<h1>Logout Page</h1>
EOD
  if ($debug) {
    print <<EOD;
<pre>
back: $back
</pre>
EOD
  }
  print <<EOD;
<p>You are now logged out.</p>
EOD
  print qq(<p><a href="$back">Previous Page</a></p>\n) if $back;
  print <<EOD;
</div>
</body>
</html>
EOD
}

# arch-tag: 09c96fc6-5119-4c79-8086-6c6b24951f96
# vim:sw=2:sm:cin

